@@ -22,6 +22,7 @@ from xpander_sdk.modules.tasks.models.task import (
 )
 from xpander_sdk.modules.tasks.models.tasks_list import TasksListItem
 from xpander_sdk.modules.tasks.sub_modules.task import Task
+from xpander_sdk.modules.tools_repository.models.mcp import MCPServerDetails
 from xpander_sdk.utils.event_loop import run_sync
 
 
@@ -53,7 +54,7 @@ class Tasks(ModuleBase):
         """
         super().__init__(configuration)
 
-    async def alist(self, agent_id: str) -> List[TasksListItem]:
+    async def alist(self, agent_id: str, filters: Optional[Dict] = None) -> List[TasksListItem]:
         """
         Asynchronously list all tasks for a specific agent.
 
@@ -62,6 +63,7 @@ class Tasks(ModuleBase):
 
         Args:
             agent_id (str): The unique identifier of the agent whose tasks should be listed.
+            filters (Optional[Dict]): Optional filters to be used on the query. supported filters: user_id, parent_task_id, triggering_agent_id, status, internal_status
 
         Returns:
             List[TasksListItem]: List of task summary objects related to the agent.
@@ -78,7 +80,8 @@ class Tasks(ModuleBase):
         try:
             client = APIClient(configuration=self.configuration)
             tasks = await client.make_request(
-                path=APIRoute.ListTasks.format(agent_id=agent_id)
+                path=APIRoute.ListTasks.format(agent_id=agent_id),
+                query=filters or {}
             )
             return [TasksListItem(**task) for task in tasks]
         except Exception as e:
@@ -86,7 +89,42 @@ class Tasks(ModuleBase):
                 raise ModuleException(e.response.status_code, e.response.text)
             raise ModuleException(500, f"Failed to list tasks - {str(e)}")
 
-    def list(self, agent_id: str) -> List[TasksListItem]:
+    async def alist_user_tasks(self, user_id: str, filters: Optional[Dict] = None) -> List[TasksListItem]:
+        """
+        Asynchronously list all tasks for a specific user.
+
+        Retrieves a list of all tasks associated with a given user, providing
+        basic information for display and selection purposes.
+
+        Args:
+            user_id (str): The unique identifier of the user whose tasks should be listed.
+            filters (Optional[Dict]): Optional filters to be used on the query. supported filters: parent_task_id, triggering_agent_id, status, internal_status
+
+        Returns:
+            List[TasksListItem]: List of task summary objects related to the user.
+
+        Raises:
+            ModuleException: If the API request fails or returns an error.
+
+        Example:
+            >>> tasks = Tasks()
+            >>> task_list = await tasks.alist(user_id="user123")
+            >>> for task in task_list:
+            ...     print(f"Task: {task.id} - Status: {task.status}")
+        """
+        try:
+            client = APIClient(configuration=self.configuration)
+            tasks = await client.make_request(
+                path=APIRoute.ListUserTasks.format(user_id=user_id),
+                query=filters or {}
+            )
+            return [TasksListItem(**task) for task in tasks]
+        except Exception as e:
+            if isinstance(e, HTTPStatusError):
+                raise ModuleException(e.response.status_code, e.response.text)
+            raise ModuleException(500, f"Failed to list user tasks - {str(e)}")
+    
+    def list(self, agent_id: str, filters: Optional[Dict] = None) -> List[TasksListItem]:
         """
         Synchronously list all tasks for a specific agent.
 
@@ -95,6 +133,7 @@ class Tasks(ModuleBase):
 
         Args:
             agent_id (str): The unique identifier of the agent whose tasks should be listed.
+            filters (Optional[Dict]): Optional filters to be used on the query. supported filters: user_id, parent_task_id, triggering_agent_id, status, internal_status
 
         Returns:
             List[TasksListItem]: List of task summary objects related to the agent.
@@ -107,7 +146,31 @@ class Tasks(ModuleBase):
             >>> task_list = tasks.list(agent_id="agent123")
             >>> print(f"Found {len(task_list)} tasks")
         """
-        return run_sync(self.alist(agent_id=agent_id))
+        return run_sync(self.alist(agent_id=agent_id,filters=filters))
+    
+    def list_user_tasks(self, user_id: str, filters: Optional[Dict] = None) -> List[TasksListItem]:
+        """
+        Synchronously list all tasks for a specific user.
+
+        This is the synchronous version of alist(). It internally calls the
+        asynchronous method and waits for completion.
+
+        Args:
+            user_id (str): The unique identifier of the user whose tasks should be listed.
+            filters (Optional[Dict]): Optional filters to be used on the query. supported filters: parent_task_id, triggering_agent_id, status, internal_status
+
+        Returns:
+            List[TasksListItem]: List of task summary objects related to the user.
+
+        Raises:
+            ModuleException: If the API request fails or returns an error.
+
+        Example:
+            >>> tasks = Tasks()
+            >>> task_list = tasks.list(user_id="user123")
+            >>> print(f"Found {len(task_list)} tasks")
+        """
+        return run_sync(self.alist_user_tasks(user_id=user_id, filters=filters))
 
     async def aget(self, task_id: str) -> Task:
         """
@@ -172,6 +235,9 @@ class Tasks(ModuleBase):
         events_streaming: Optional[bool] = False,
         additional_context: Optional[str] = None,
         expected_output: Optional[str] = None,
+        mcp_servers: Optional[List[MCPServerDetails]] = [],
+        triggering_agent_id: Optional[str] = None,
+        title: Optional[str] = None,
     ) -> Task:
         """
         Asynchronously create a new task for a specific agent.
@@ -195,6 +261,9 @@ class Tasks(ModuleBase):
             events_streaming (Optional[bool]): Flag idicating for events are required for this task.
             additional_context (Optional[str]): Additional context to be passed to the agent.
             expected_output (Optional[str]): Expected output of the execution.
+            mcp_servers (Optional[List[MCPServerDetails]]): Optional list of mcp servers to use.
+            triggering_agent_id (Optional[str]): Optional triggering agent id.
+            title (Optional[str]): Optional task title.
 
         Returns:
             Task: Newly created task object containing all initial configuration data.
@@ -234,7 +303,10 @@ class Tasks(ModuleBase):
                     "run_locally": run_locally,
                     "events_streaming": events_streaming,
                     "additional_context": additional_context,
-                    "expected_output": expected_output
+                    "expected_output": expected_output,
+                    "mcp_servers": [server.model_dump() for server in mcp_servers],
+                    "triggering_agent_id": triggering_agent_id,
+                    "title": title
                 },
             )
             return Task(**created_task, configuration=self.configuration)
